@@ -20,15 +20,15 @@
 #include "signatureconfigurator.h"
 #include "identity.h"
 
-#include <kactioncollection.h>
-#include <klocalizedstring.h>
+#include <KActionCollection>
+#include <KLocalizedString>
 #include "kidentitymanagement_debug.h"
-#include <klineedit.h>
-#include <kurlrequester.h>
-#include <kshellcompletion.h>
-#include <ktoolbar.h>
+#include <KLineEdit>
+#include <KUrlRequester>
+#include <KShellCompletion>
+#include <KToolBar>
 #include <KMessageBox>
-#include <krun.h>
+#include <KRun>
 #include <QUrl>
 
 #include <KPIMTextEdit/RichTextComposer>
@@ -141,7 +141,11 @@ void SignatureConfigurator::Private::init()
     QStackedWidget *widgetStack = new QStackedWidget(q);
     widgetStack->setEnabled(false);   // since !mEnableCheck->isChecked()
     vlay->addWidget(widgetStack, 1);
+#if QT_VERSION < QT_VERSION_CHECK(5, 15, 0)
     q->connect(mSourceCombo, QOverload<int>::of(&QComboBox::currentIndexChanged), widgetStack, &QStackedWidget::setCurrentIndex);
+#else
+    q->connect(mSourceCombo, QOverload<int, const QString &>::of(&QComboBox::currentIndexChanged), widgetStack, &QStackedWidget::setCurrentIndex);
+#endif
     q->connect(mSourceCombo, QOverload<int>::of(&QComboBox::highlighted), widgetStack, &QStackedWidget::setCurrentIndex);
     // connects for the enabling of the widgets depending on
     // signatureEnabled:
